@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.24 2004/11/24 19:35:58 vnoel Exp $ */
+/* $Id: dict.c,v 1.27 2005/07/05 16:01:12 vnoel Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -28,8 +28,8 @@
 
 #include <unistd.h>
 
-#include <glib.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 #include "dict.h"
 
@@ -687,7 +687,7 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
 						     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
 						     "<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
 						     _("Server Error"),
-						     _("A serious error occured. Please check that your server and port are correct. For reference the default server is dict.org and the port 2628"));
+						     _("A serious error occurred. Please check that your server and port are correct. For reference the default server is dict.org and the port 2628"));
         g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
                                   G_CALLBACK (gtk_widget_destroy),
                                   GTK_OBJECT (dialog));
@@ -769,9 +769,16 @@ void dict_context_destroy (dict_context_t *context)
     dict_disconnect (context);
     g_free (context->hostname);
     context->hostname = NULL;
+
+    if (context->command != NULL) {
+      g_free (context->command);
+    }
+
     /* FOOOOOOOO, HAAAAAAAAAAACK, the notify handler still gets called,
      * I do not understand this, this keeps it from dieing */
     /*g_free (context);*/
+    /* FIXME: Are these hacks still necessary? */
+    g_free (context);
 }
 
 /* dict_connect (context)
