@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.143 2005/07/05 16:01:12 vnoel Exp $ */
+/* $Id: gdict-app.c,v 1.144 2005/09/23 14:34:39 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -233,7 +233,7 @@ gdict_lookup_button_drag_cb (GtkWidget *widget, GdkDragContext *context, gint x,
   gchar *text;
   GDictWindow *gdict = data;
 
-  text = gtk_selection_data_get_text (sd);
+  text = (gchar *) gtk_selection_data_get_text (sd);
 
   if (text) {
     gtk_entry_set_text (GTK_ENTRY (gdict->word_entry), text);
@@ -469,20 +469,6 @@ gdict_view_spellings_cb (GtkAction *action, GtkWidget *widget)
   }
 }
 
-static void
-gdict_zoom_in (GtkAction *action, GtkWidget *widget)
-{
-	GDictWindow *gdict = GDICT_WINDOW (widget);
-	gdict_defbox_zoom_in (gdict->defbox);
-}
-
-static void
-gdict_zoom_out (GtkAction *action, GtkWidget *widget)
-{
-	GDictWindow *gdict = GDICT_WINDOW (widget);
-	gdict_defbox_zoom_out (gdict->defbox);
-}
-
 static void
 gdict_help_contents_cb (GtkAction *action, GtkWidget *widget)
 {
@@ -539,10 +525,9 @@ gdict_window_new (void)
   gdict->search_type = SEARCH_TYPE_REGULAR;
   gdict->web_search_sites = gdict_web_search_default_sites ();
   gdict_windows = g_slist_prepend (gdict_windows, window);
-	if (gdict->pref->fontname) {
+	if (gdict->pref->fontname)
 		gdict_defbox_set_font (gdict->defbox, gdict->pref->fontname);
-		gdict_defbox_set_fontsize (gdict->defbox, gdict->pref->fontsize);
-	} else
+	else
 		gdict_window_store_font (gdict);
   return window;
 }
@@ -572,9 +557,6 @@ static const gchar ui_info[] =
 "    </menu>"
 "    <menu action='ViewMenu'>"
 "      <menuitem action='ViewSpellings'/>"
-"      <separator/>"
-"      <menuitem action='ViewZoomIn'/>"
-"      <menuitem action='ViewZoomOut'/>"
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='HelpContents'/>"
@@ -607,12 +589,6 @@ static const GtkActionEntry menu_entries[] = {
   { "Preferences", GTK_STOCK_PREFERENCES, N_("P_references"), NULL,
     N_("Configure the application"), G_CALLBACK (gdict_preferences_cb) },
 
-	/* View menu */
-	{"ViewZoomIn", GTK_STOCK_ZOOM_IN, NULL, "<control>plus", N_("Bigger text size"),
-	 G_CALLBACK (gdict_zoom_in)},
-	{"ViewZoomOut", GTK_STOCK_ZOOM_OUT, NULL, "<control>minus", N_("Smaller text size"),
-	 G_CALLBACK (gdict_zoom_out)},
-
   /* Help menu */
   { "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
      N_("View help for this application"), G_CALLBACK (gdict_help_contents_cb) },
