@@ -1,7 +1,4 @@
-#ifndef __GDICT_PREF_DIALOG_H_
-#define __GDICT_PREF_DIALOG_H_
-
-/* $Id: gdict-pref-dialog.h,v 1.12 2005/05/25 14:53:58 vnoel Exp $ */
+/* $Id: gdict-pref-dialog.h,v 1.14 2005/06/15 18:54:40 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -15,8 +12,12 @@
  *
  */
 
+#ifndef GDICT_PREF_DIALOG_H
+#define GDICT_PREF_DIALOG_H
+
+G_BEGIN_DECLS
+
 #include <gtk/gtk.h>
-	
 #include "dict.h"
 #include "gdict-app.h"
 #include "gdict-pref.h"
@@ -32,6 +33,7 @@ typedef struct _GDictPrefDialog        GDictPrefDialog;
 typedef struct _GDictPrefDialogClass   GDictPrefDialogClass;
 	
 struct _GDictPrefDialog {
+
     GtkDialog       dialog;
 
     GtkTable         *table;
@@ -50,6 +52,7 @@ struct _GDictPrefDialog {
     GtkWidget        *view;
     GtkWidget        *remove_button;
     GtkWidget        *font_button;
+    GtkOptionMenu    *db_option_menu, *strat_option_menu;
 
     dict_context_t   *context;
     dict_command_t   *get_db_cmd;
@@ -67,8 +70,9 @@ struct _GDictPrefDialogClass {
 };
 
 GType      gdict_pref_dialog_get_type   (void);
-	
 GtkWidget *gdict_pref_dialog_new        (GDictWindow *gdict);
-void       gdict_pref_dialog_destroy          (GDictPrefDialog *dialog);
+void       gdict_pref_dialog_destroy    (GDictPrefDialog *dialog);
 
-#endif /* __GDICT_PREF_DIALOG_H_ */
+G_END_DECLS
+
+#endif /* GDICT_PREF_DIALOG_H */
