@@ -47,6 +47,7 @@ extern "C" {
 #define MINIMUM_WINDOW_WIDTH   420
 #define MINIMUM_WINDOW_HEIGHT  310
 #define WINDOW_HEIGHT_STEP      35
+#define NUM_VISIBLE_COLUMNS      5
 
 typedef enum {
 	STOPPED,
@@ -89,6 +90,7 @@ struct _GSearchWindow {
 	GtkWidget             * progress_spinner;
 	GtkWidget             * find_button;
 	GtkWidget             * stop_button;
+	GtkWidget             * focus;
 
 	GtkWidget             * show_more_options_expander;
 	GtkWidget             * available_options_vbox;
@@ -107,9 +109,11 @@ struct _GSearchWindow {
 	GtkCellRenderer       * search_results_name_cell_renderer;
 	GtkTreeSelection      * search_results_selection;
 	GtkTreeIter             search_results_iter;
+	GtkTreePath           * search_results_hover_path;
 	GHashTable            * search_results_filename_hash_table;
 	GHashTable            * search_results_pixbuf_hash_table;
 	gchar                 * search_results_date_format_string;
+	GnomeThumbnailFactory * thumbnail_factory;
 	gint		        show_thumbnails_file_size_limit;
 	gboolean		show_thumbnails;
 	gboolean                is_search_results_single_click_to_activate;
